@@ -3,15 +3,15 @@ package WWW::BashOrg;
 use warnings;
 use strict;
 
-our $VERSION = '1.001001'; # VERSION
+our $VERSION = '1.001002'; # VERSION
 
 use LWP::UserAgent;
 use HTML::TokeParser::Simple;
 use HTML::Entities;
 use overload q|""| => sub { shift->quote };
-use base 'Class::Data::Accessor';
+use base 'Class::Accessor::Grouped';
 
-__PACKAGE__->mk_classaccessors(qw/
+__PACKAGE__->mk_group_accessors( simple => qw/
     ua
     error
     quote
